Computation of confidence intervals for the AUC by implementing the empirical procedure for estimating the variance of the AUC, as described in tools:::Rd_expr_doi("10.1515/ijb-2019-0097").
auc_ci_empr(SE, SP, auc, probs, controls, cases, ci.cl)List with two components:
lower edge of the confidence interval.
upper edge of the confidence interval.
vector containing the values of the sensitivity returned from the sMSROC function.
vector containing the values of the specificity.
value with the AUC estimate.
vector containing the probabilities estimated through the predictive model.
number of negative individuals.
number of positive individuals.
confidence level at which confidence intervals will be computed.