check_ci_cl: Check confidence level for AUC's confidence intervals

View source: R/CheckFunctions.R

check_ci_cl-internalR Documentation

Check confidence level for AUC's confidence intervals

Description

Checks the validity of the value entered as confidence level for computing the confidence intervals for the AUC.

Usage

check_ci_cl(ci.cl)

Arguments

ci.cl

confidence level at which the confidence intervals for the AUC will be computed.

Details

Verifies that the value entered as confidence level ranges between 0 and 1. The 0.95 confidence level is taken as default.

Value

A list with two components:

ci.cl

value entered as confidence level for the AUC.

message

table with the warning messages generated by the function.


sMSROC documentation built on May 29, 2024, 1:43 a.m.

Related to check_ci_cl in sMSROC...