Check of the consistency of the parameters indicated to compute the confidence intervals for the AUC.
check_conf_int(conf.int, ci.cl, ci.meth, ci.nboots, parallel, ncpus)A list with the following components:
value entered as confidence level for the AUC.
value entered as method for computing the confidence intervals.
value entered as number of bootstrap samples.
value entered as number of CPUs chosen.
table with the warning messages generated by the function.
parameter indicating whether confidence intervals for the AUC will be computed (``T'') or not (``F''). The default is ``F''.
confidence level at which the confidence intervals for the AUC will be calculated. The default value is 0.95.
method for computing the confidence intervals according to tools:::Rd_expr_doi("10.1515/ijb-2019-0097"). There are three options:
``E'', for the Empirical variance estimation.
``V'', for the theoretical Variance estimation.
``B'', for the Bootstrap Percentile.
The empirical method E is taken as default. This parameter is ignored if conf.int is set to ``F''.
number of bootstrap samples to be generated when the chosen ci.meth is ``B''. The default values is 500.
indicates whether parallel computing will be done (``T'') or not (``F''), when computing the variance of the AUC through the methods ``V'' and ``B''.
number of CPUS that will be used when parallel computing is chosen.