Checks the consistency of the parameters entered for prognosis scenarios under interval censorship.
check_marker_timeic(marker, left, right, time, probs, sd.probs)The function returns a list with the following components:
vector containing the biomarker values.
vector containing the lower edges of the observed intervals.
vector containing the upper edges of the observed intervals.
vector with the probabilities corresponding to the predictive model.
vector containing the standard deviations of the predictive model if they have been manually entered.
vector with the condition of the subjects at the time time, as positive, negative or unknown.
number of negative subjects.
number of positive subjects.
number of subjects whose condition is unknown.
table containing the warning messages generated during the execution of the function.
vector with the biomarker values. It is a mandatory parameter.
vector containing the lower edges of the observed intervals. It is mandatory in prognosis scenarios and interval censorship and ignored in other situations.
vector with the upper edges of the observed intervals. It is mandatory as well in prognosis scenarios and interval censorship and ignored in other situations.
point of time at which the sMS ROC curve estimator will be computed. It is a mandatory parameter. The default value is 1.
vector containing the probabilities corresponding to the predictive model when it has been externally computed. Only values between [0,1] are admissible.
vector with the standard deviations of the probabilities entered in probs. It is an optional parameter.
check_marker_binout and check_marker_timerc