| check_meth-internal | R Documentation |
When the predictive model is entered manually by the user, this function ensures that no other method by default is used to compute it.
check_meth(meth, probs)
meth |
method for approximating the predictive model |
probs |
vector containing the probabilities corresponding to the predictive model when it is entered manually by the user. |
If the predicitve model has been manually indicated, this function sets the parameter to "M" ignoring other options. In this way, none of the function computing the predictive model will be called.
A list with one component:
meth |
value set up for the method parameter.It can take eiter the value entered by the user or its default, if the predictive model was not manually indicated, or the value "M", when the predicitive model was entered in the parameter |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.