Learn R Programming

sMSROC (version 0.1.3)

check_nboots-internal: Check number of bootstrap samples

Description

This function checks if the value entered as number of bootstrap samples is correct.

Usage

check_nboots(nboots)

Value

A list with two components:

nboots

value entered as number of bootstrap samples.

message

table with the warning messages generated by the function.

Arguments

nboots

number of bootstrap samples to be run. The default value is 500.