check_ncpus: Check number of CPUs

View source: R/CheckFunctions.R

check_ncpus-internalR Documentation

Check number of CPUs

Description

Checks the number of CPUs to be used when parallel computing is performed. The default value is 1 and the maximum is 2.

Usage

check_ncpus(ncpus)

Arguments

ncpus

number of CPUs to be used when performing parallel computing.

Value

A list with two components:

ncpus

value entered as number of CPUs chosen.

message

table with the warning messages generated by the function.


sMSROC documentation built on May 29, 2024, 1:43 a.m.

Related to check_ncpus in sMSROC...