Learn R Programming

sMSROC (version 0.1.3)

check_ncpus-internal: Check number of CPUs

Description

Checks the number of CPUs to be used when parallel computing is performed. The default value is 1 and the maximum is 2.

Usage

check_ncpus(ncpus)

Value

A list with two components:

ncpus

value entered as number of CPUs chosen.

message

table with the warning messages generated by the function.

Arguments

ncpus

number of CPUs to be used when performing parallel computing.