| conf_int_print | R Documentation |
Prints the AUC estimate value and its confidence intervals computed by the sMSROC function.
conf_int_print(sMS)
sMS |
object of class |
This function reads the AUC, lower and upper edges of its confidence intervals and the confidence level at which they were computed and prints this information in a single line.
Printed string in the console containing the AUC, its confidence intervals and the confidence level at which they were computed.
sMSROC
data(diabet)
roc <- sMSROC(marker=diabet$stab.glu, status=diabet$glyhb, conf.int="T")
conf_int_print(roc)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.