Learn R Programming

sMSROC (version 0.1.3)

diabet: Diabetes dataset

Description

This dataset contains part of the Diabetes Dataset (see References), courtesy of Dr John Schorling from the Department of Medicine, University of Virginia School of Medicine. This version contains 3 variables on 403 subjects interviewed to understand the prevalence of several cardiovascular risks factors in central Virginia for African Americans.

Usage

data("diabet")

Arguments

Format

A data frame with 403 observations on the following 3 variables.

stab.glu

a numeric vector indicating the level of stabilized glucose.

glyhb

a numeric vector indicating the level of glycosolated hemoglobin.

age

age in years of the participants.

diab

a numeric vector indicating whether the subject is diagnosed as diabetic (value = 1) or not (value = 0).

Details

The diab variable is not present in the original dataset. Here, values of glycosolated hemoglobin > 7.0 were taken as a positive diagnosis of diabetes (diab = 1) and those of glycosolated hemoglobin <= 7.0 as a negative diagnosis (diab = 0).

References

Willems JP, Saunders JT, Hunt DE, Schorling JB. Prevalence of coronary heart disease risk factors among rural blacks: a community-based study. South Med J. 1997 Aug;90(8):814-20. PMID: 9258308.

Examples

Run this code
data(diabet)
summary(diabet)

Run the code above in your browser using DataLab