| fibrosis | R Documentation |
Synthetic dataset generated to simulate data from a study that aimed to assess the predictive ability of a constructed score to determine the worsening in the fibrosis stage in individuals infected by the hepatitis C (HC) virus. When participants underwent a target revision, their fibrosis stage, certain polymorphisms, and other clinical variables were collected. Highest stages of fibrosis were considered a worsening in the disease. See References for more information about the study.
data("fibrosis")
A data frame with 722 observations and the following variables:
IdIdentification label for each participant.
ScoreScore proposed to stratify participants infected by the HC virus according to the risk of a worsening in their fibrosis stage.
StartLower edge of the observable interval.
StopUpper edge of the observable interval. It can take the value infinity, represented as Inf.
Synthetic dataset.
Vidal-Castineira JR. al. Genetic contribution of endoplasmic reticulum aminopeptidase 1 polymorphisms to liver fibrosis progression in patients with HCV infection. Journal of Molecular Medicine, 98:1245-1254, 2020. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s00109-020-01948-1")}
data(fibrosis)
summary(fibrosis)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.