| ktfs | R Documentation |
Dataset originally delivered in the RISCA package. It contains data from kidney transplant recipients for whom the Kidney Transplant Failure Score (KTFS) was collected. The KTFS is a score proposed by Foucher et al. (2010) (see References) to assess the recipients according to their risk of returning in dialysis.
data("ktfs")
A data frame with 2169 observations and the following 3 variables:
timea numeric vector depicting the follow-up time in years.
failurea numeric vector indicating the graft failure at the end of the follow-up (1-Yes, 0-Censoring).
scorea numeric vector representing the KTFS value.
This dataset is available at RISCA package. More information about the KTFS score can be found at https://www.divat.fr.
Foucher Y. al. A clinical scoring system highly predictive of long-term kidney graft survival. Kidney International, 78:1288-94, 2020. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1038/ki.2010.232")}.
data(ktfs)
summary(ktfs)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.