| probs_pred | R Documentation |
This function plots the predicted probabilities for each marker value computed through the predictive model together, with 95% pointwise confidence intervals.
probs_pred(sMS, var, nboots, parallel, ncpus)
sMS |
object of class |
var |
parameter indicating whether 95% pointwise confidence intervals for the predictive model will be plotted (value "T") or not (value "F"). The default value is "F". |
nboots |
number of bootstrap samples to be generated for computing the pointwise confidence intervals. The default value is 500. |
parallel |
parameter indicating whether parallel computing will be performed (value "T") or not (value "F"). The default is âFâ. |
ncpus |
number of CPUS to be used in the case of carrying out parallel computing. The default value is 1 and the maximum is 2. |
The function plots the probability function estimation of the predictive model versus the biomaker. It also computes and plots 95% pointwise confidence intervals on the same graphic when the var parameter is set to "T".
The variance of the probability estimates, obtained by the predictive model, is computed via bootstrap with nboots samples.
A list with these components:
plot |
object of class |
thres |
ordered biomarker values (x-axis coordinates). |
probs |
predicted probabilities (y-axis coordinates). |
sd.probs |
estimates of the standard deviation of the predicted probabilities. |
pred_model_binout, pred_model_timerc and pred_model_timeic
data(ktfs)
DT <- ktfs
roc <- sMSROC(marker = DT$score,
status = DT$failure,
observed.time = DT$time,
time = 5,
meth = "S")
probs <- probs_pred(sMS = roc)
probs$plot
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.