View source: R/CheckFunctions.R
| check_ci_cl-internal | R Documentation |
Checks the validity of the value entered as confidence level for computing the confidence intervals for the AUC.
check_ci_cl(ci.cl)
ci.cl |
confidence level at which the confidence intervals for the AUC will be computed. |
Verifies that the value entered as confidence level ranges between 0 and 1. The 0.95 confidence level is taken as default.
A list with two components:
ci.cl |
value entered as confidence level for the AUC. |
message |
table with the warning messages generated by the function. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.