Checks the validity of the value entered as confidence level for computing the confidence intervals for the AUC.
check_ci_cl(ci.cl)A list with two components:
value entered as confidence level for the AUC.
table with the warning messages generated by the function.
confidence level at which the confidence intervals for the AUC will be computed.
Verifies that the value entered as confidence level ranges between 0 and 1. The 0.95 confidence level is taken as default.