powered by
This function checks if the value entered as number of bootstrap samples is correct.
check_nboots(nboots)
A list with two components:
value entered as number of bootstrap samples.
table with the warning messages generated by the function.
number of bootstrap samples to be run. The default value is 500.