View source: R/CheckFunctions.R
| check_ncpus-internal | R Documentation |
Checks the number of CPUs to be used when parallel computing is performed. The default value is 1 and the maximum is 2.
check_ncpus(ncpus)
ncpus |
number of CPUs to be used when performing parallel computing. |
A list with two components:
ncpus |
value entered as number of CPUs chosen. |
message |
table with the warning messages generated by the function. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.