powered by
Checks the number of CPUs to be used when parallel computing is performed. The default value is 1 and the maximum is 2.
check_ncpus(ncpus)
A list with two components:
value entered as number of CPUs chosen.
table with the warning messages generated by the function.
number of CPUs to be used when performing parallel computing.