Learn R Programming

sMSROC (version 0.1.3)

conf_int_print: AUC and confidence intervals

Description

Prints the AUC estimate value and its confidence intervals computed by the sMSROC function.

Usage

conf_int_print(sMS)

Value

Printed string in the console containing the AUC, its confidence intervals and the confidence level at which they were computed.

Arguments

sMS

object of class sMS returned by the function sMSROC.

Details

This function reads the AUC, lower and upper edges of its confidence intervals and the confidence level at which they were computed and prints this information in a single line.

See Also

sMSROC

Examples

Run this code
data(diabet)
roc <- sMSROC(marker=diabet$stab.glu, status=diabet$glyhb, conf.int="T")
conf_int_print(roc)

Run the code above in your browser using DataLab