Prints the AUC estimate value and its confidence intervals computed by the sMSROC function.
Usage
conf_int_print(sMS)
Value
Printed string in the console containing the AUC, its confidence intervals and the confidence level at which they were computed.
Arguments
sMS
object of class sMS returned by the function sMSROC.
Details
This function reads the AUC, lower and upper edges of its confidence intervals and the confidence level at which they were computed and prints this information in a single line.